        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 25 <strong>control</strong><br>0,1,2,3,9,10,11,12,14,16,18,26,27,28,30,31,32,37,40,42,43,44,45,46,49';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 16 <br>4,5,6,7,8,13,15,20,21,24,33,34,36,39,47,48';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 10 <br>17,19,22,23,25,29,35,38,41,50';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 25 <strong>control</strong><br>0,1,2,3,9,10,11,12,14,16,18,26,27,28,30,31,32,37,40,42,43,44,45,46,49';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 16 <br>4,5,6,7,8,13,15,20,21,24,33,34,36,39,47,48';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 10 <br>17,19,22,23,25,29,35,38,41,50';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 25 <strong>control</strong><br>0,1,2,3,9,10,11,12,14,16,18,26,27,28,30,31,32,37,40,42,43,44,45,46,49';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 16 <br>4,5,6,7,8,13,15,20,21,24,33,34,36,39,47,48';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 10 <br>17,19,22,23,25,29,35,38,41,50';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 25 <strong>control</strong><br>0,1,2,3,9,10,11,12,14,16,18,26,27,28,30,31,32,37,40,42,43,44,45,46,49';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 16 <br>4,5,6,7,8,13,15,20,21,24,33,34,36,39,47,48';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 10 <br>17,19,22,23,25,29,35,38,41,50';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 25 <strong>control</strong><br>0,1,2,3,9,10,11,12,14,16,18,26,27,28,30,31,32,37,40,42,43,44,45,46,49';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 16 <br>4,5,6,7,8,13,15,20,21,24,33,34,36,39,47,48';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 10 <br>17,19,22,23,25,29,35,38,41,50';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 25 <strong>control</strong><br>0,1,2,3,9,10,11,12,14,16,18,26,27,28,30,31,32,37,40,42,43,44,45,46,49';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 16 <br>4,5,6,7,8,13,15,20,21,24,33,34,36,39,47,48';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260624 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 10 <br>17,19,22,23,25,29,35,38,41,50';}
}
